@@ -34,8 +34,7 @@ class KCMDesignerFields : public KCModule
 {
     Q_OBJECT
 public:
-    explicit KCMDesignerFields(QWidget *parent = nullptr,
-                               const QVariantList &args = QVariantList());
+    explicit KCMDesignerFields(QWidget *parent = nullptr, const QVariantList &args = QVariantList());
 
     void load() override;
     void save() override;
