@@ -41,7 +41,7 @@ public:
     ~MultiAgendaView() override;
 
     Akonadi::Item::List selectedIncidences() override;
-    KCalCore::DateList selectedIncidenceDates() override;
+    KCalendarCore::DateList selectedIncidenceDates() override;
     int currentDateCount() const override;
     int maxDatesHint() const override;
 
